//=============================================================================
// BattleSystem.cpp
//=============================================================================
#include "Stdinc.h"
#include "BattleSystem.h"
#include "DisplayManager.h"
#include "Manipulator.h"

#include "Character.h"
#include "Enemy.h"
#include "Field.h"
//-----------------------------------------------------------------------------
// RXgN^
//-----------------------------------------------------------------------------
CBattleSystem::CBattleSystem(void)
{
	// p[eB
	RtlZeroMemory( m_pPlayerParty, sizeof(m_pPlayerParty) );

	// Gp[eB
	RtlZeroMemory( m_pEnemyParty, sizeof(m_pEnemyParty) );

	// \}l[W
	m_pDisplayMan = new CDisplayManager();

	// Ǘ
	m_pManipulator = new CManipulator();

	// tB[h
	m_pField = new CField();
}

//-----------------------------------------------------------------------------
// fXgN^
//-----------------------------------------------------------------------------
CBattleSystem::~CBattleSystem(void)
{
	for ( int iCnt = 0; iCnt < BATTLE_CHAR_COUNT_MAX; iCnt ++ )
	{
		if ( m_pPlayerParty[iCnt] )
		{
			delete m_pPlayerParty[iCnt];
		}
	}
	for ( int iCnt = 0; iCnt < BATTLE_ENEMY_COUNT_MAX; iCnt ++ )
	{
		if ( m_pEnemyParty[iCnt] )
		{	delete m_pEnemyParty[iCnt];	}
	}
	delete m_pField;
	delete m_pManipulator;
	delete m_pDisplayMan;
}
//-----------------------------------------------------------------------------
// GetInstance
//-----------------------------------------------------------------------------
CBattleSystem *CBattleSystem::GetInstance( void )
{
	static CBattleSystem m_Instance;
	return &m_Instance;
}
//-----------------------------------------------------------------------------
// Initialize
// 
//-----------------------------------------------------------------------------
BOOL CBattleSystem::Initialize( void )
{
	BOOL bRet = TRUE;

	int nDebugFieldID = 1;

	// n`Awiݒ
	m_pField->Initialize( nDebugFieldID );

	// GJEgGl~[ݒ
	Debug_SetupEnemyInfo( m_pEnemyParty );

	// p[eBݒ
	Debug_SetupPartyInfo( m_pPlayerParty );

	// AACeʂł̃p[eB[C

	// ATBlݒ

	// \}l[W
	bRet &= m_pDisplayMan->Initialize( m_pPlayerParty, m_pEnemyParty, m_nEnemyCount, m_pField );

	return bRet;
}
//-----------------------------------------------------------------------------
// Debug_SetupPartyInfo
// fobOpp[eBݒ
//-----------------------------------------------------------------------------
void CBattleSystem::Debug_SetupPartyInfo( CCharacter **m_pPlayerParty )
{
	for ( int iCnt = 0; iCnt < BATTLE_CHAR_COUNT_MAX; iCnt ++ )
	{
		if ( m_pPlayerParty[iCnt] )
		{	delete m_pPlayerParty[iCnt];	}

		m_pPlayerParty[iCnt] = new CCharacter();
		m_pPlayerParty[iCnt]->m_nMaxHP = 1000 + iCnt * 100;

		m_pPlayerParty[iCnt]->m_nHP    = iCnt * 600;
	}
	
	m_pPlayerParty[0]->SetName( "eXgY" );
	m_pPlayerParty[1]->SetName( "eXgY" );
	m_pPlayerParty[2]->SetName( "eXgOY" );
	m_pPlayerParty[3]->SetName( "eXglN" );
}
//-----------------------------------------------------------------------------
// Debug_SetupEnemyInfo
// fobOpGp[eBݒ
//-----------------------------------------------------------------------------
void CBattleSystem::Debug_SetupEnemyInfo( CEnemy **m_pEnemyParty )
{
	// 
	for ( int iCnt = 0; iCnt < BATTLE_ENEMY_COUNT_MAX; iCnt ++ )
	{
		if ( m_pEnemyParty[iCnt] )
		{	delete m_pEnemyParty[iCnt];	}

		m_pEnemyParty[iCnt] = NULL;
	}

	m_nEnemyCount = 5;
	for ( int iCnt = 0; iCnt < 4; iCnt ++ )
	{
		m_pEnemyParty[iCnt] = new CEnemy();

		// ToDo: A[JCu}l[WIȂ̂ 
		m_pEnemyParty[iCnt]->m_lpzFileName = ENEMY_FILE_NAME_01;
		m_pEnemyParty[iCnt]->m_nHP = 200;
		// ToDo: A[JCu}l[WIȂ̂ 

		m_pEnemyParty[iCnt]->Initialize( 1 /*ID*/ );
		strncpy_s( m_pEnemyParty[iCnt]->m_szName, "TnM", _countof(m_pEnemyParty[iCnt]->m_szName) );

	}

	m_pEnemyParty[4] = new CEnemy();
	// ToDo: A[JCu}l[WIȂ̂ 
	m_pEnemyParty[4]->m_lpzFileName = ENEMY_FILE_NAME_02;
	m_pEnemyParty[4]->m_nHP = 500;
	// ToDo: A[JCu}l[WIȂ̂ 

	m_pEnemyParty[4]->Initialize( 2 );
	strncpy_s( m_pEnemyParty[4]->m_szName, "TnM`[t", _countof(m_pEnemyParty[4]->m_szName) );

	m_pEnemyParty[0]->SetDispPos(  10, 60 );
	m_pEnemyParty[1]->SetDispPos(  60, 60 );
	m_pEnemyParty[2]->SetDispPos( 110, 60 );
	m_pEnemyParty[3]->SetDispPos(  35,110 );
	m_pEnemyParty[4]->SetDispPos(  85,110 );
}

//-----------------------------------------------------------------------------
// FrameMove
// XV
//-----------------------------------------------------------------------------
void CBattleSystem::FrameMove( void )
{
	if ( GetActiveFlag() )
	{
		m_pManipulator->CheckKeyState();
	}
	m_pDisplayMan->FrameMove();
}

//-----------------------------------------------------------------------------
// Render
// `
//-----------------------------------------------------------------------------
void CBattleSystem::Render( void )
{
	m_pDisplayMan->Render();
}
